@@ -4,4 +4,4 @@ import os
 data_dir = os.path.dirname(os.path.abspath(other.__file__))
 
 def read(data_dir):
-	return pd.read_excel(data_dir+'/rules.xlsx',index_col=0)
\ No newline at end of file
+	return pd.read_excel(data_dir+'\\rules.xlsx',index_col=0)
\ No newline at end of file
